@@ -1,23 +1,24 @@
 from django.contrib.auth import get_user_model
 from django.core import validators
+from django.test import TestCase
 from django.test.client import Client
 from django.test.utils import override_settings
 from django.urls import reverse
 
 from allauth.account import app_settings
 from allauth.account.signals import user_logged_out
-from allauth.tests import Mock, TestCase
+from allauth.tests import Mock
 
 
 test_username_validators = [
-    validators.RegexValidator(regex=r"^[a-c]+$", message="not abc", flags=0)
+    validators.RegexValidator(regex=r"^[a-c]+$", message="not abc")
 ]
 
 
 @override_settings(
     ACCOUNT_DEFAULT_HTTP_PROTOCOL="https",
     ACCOUNT_EMAIL_VERIFICATION=app_settings.EmailVerificationMethod.MANDATORY,
-    ACCOUNT_AUTHENTICATION_METHOD=app_settings.AuthenticationMethod.USERNAME,
+    ACCOUNT_LOGIN_METHODS={app_settings.LoginMethod.USERNAME},
     ACCOUNT_SIGNUP_FORM_CLASS=None,
     ACCOUNT_EMAIL_SUBJECT_PREFIX=None,
     LOGIN_REDIRECT_URL="/accounts/profile/",
