@@ -1,7 +1,8 @@
-# -*- coding: utf-8 -*-
+from django.test import TestCase
+
 from allauth.socialaccount.providers.exist.provider import ExistProvider
 from allauth.socialaccount.tests import OAuth2TestsMixin
-from allauth.tests import MockedResponse, TestCase
+from allauth.tests import MockedResponse
 
 
 class ExistTests(OAuth2TestsMixin, TestCase):
@@ -32,3 +33,6 @@ class ExistTests(OAuth2TestsMixin, TestCase):
             }
         """,
         )
+
+    def get_expected_to_str(self):
+        return "josh"
